@@ -6,9 +6,9 @@ Type annotations for codeguru-reviewer service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_codeguru_reviewer.literals import EncryptionOption
+    from mypy_boto3_codeguru_reviewer.literals import EncryptionOptionType
 
-    data: EncryptionOption = "AWS_OWNED_CMK"
+    data: EncryptionOptionType = "AWS_OWNED_CMK"
     ```
 """
 import sys
@@ -20,22 +20,22 @@ else:
 
 
 __all__ = (
-    "EncryptionOption",
-    "JobState",
+    "EncryptionOptionType",
+    "JobStateType",
     "ListRepositoryAssociationsPaginatorName",
-    "ProviderType",
-    "Reaction",
-    "RepositoryAssociationState",
+    "ProviderTypeType",
+    "ReactionType",
+    "RepositoryAssociationStateType",
     "TypeType",
 )
 
 
-EncryptionOption = Literal["AWS_OWNED_CMK", "CUSTOMER_MANAGED_CMK"]
-JobState = Literal["Completed", "Deleting", "Failed", "Pending"]
+EncryptionOptionType = Literal["AWS_OWNED_CMK", "CUSTOMER_MANAGED_CMK"]
+JobStateType = Literal["Completed", "Deleting", "Failed", "Pending"]
 ListRepositoryAssociationsPaginatorName = Literal["list_repository_associations"]
-ProviderType = Literal["Bitbucket", "CodeCommit", "GitHub", "GitHubEnterpriseServer"]
-Reaction = Literal["ThumbsDown", "ThumbsUp"]
-RepositoryAssociationState = Literal[
+ProviderTypeType = Literal["Bitbucket", "CodeCommit", "GitHub", "GitHubEnterpriseServer"]
+ReactionType = Literal["ThumbsDown", "ThumbsUp"]
+RepositoryAssociationStateType = Literal[
     "Associated", "Associating", "Disassociated", "Disassociating", "Failed"
 ]
 TypeType = Literal["PullRequest", "RepositoryAnalysis"]
